==> steward-app-1.19.0.jar: client/src/app/common/authentication/authentication.js <==
/**
 * Created by ben on 2/12/15.
 */
angular.module("hms-authentication", ['ngCookies', 'hms-authentication-model'])
    .constant("UserRoles", {
        ROLE1: "Researcher",
        ROLE2: "DataSteward",
        ROLE3: "Admin"
    })
    .factory('HMSAuthenticationService', ['$http', '$q', '$cookieStore', '$app', 'HMSAuthenticationModel', function ($http, $q, $cookieStore, $app, model) {

        var service     = {},
            researcher  = {username: 'ben',     password: 'kapow',  roles: ['researcher']},
            steward     = {username: 'dave',    password: 'kablam', roles: ['steward']};


        function SetUserRoles (roles) {
            return (username === "ben") ? researcher.roles : steward.roles;
        }

        service.Login = function () {
            return model.authenticate();
        };


        service.GetGlobalsCookie = function () {
            $cookieStore.get("globals");
        };

        service.SetAuthHeader = function (username, password) {
            var authdata = $app.utils.toBase64(username + ':' + password);
            $http.defaults.headers.common['Authorization'] =  'Basic ' + authdata;
        };

        service.SetCredentials = function (username, password, roles) {
            var authdata = $app.utils.toBase64(username + ':' + password);
            $app.utils.setAppUser(username, authdata, roles);
        };

        service.ClearCredentials = function () {
            if($app.globals.currentUser !== undefined) {
                $app.globals.currentUser.isLoggedIn = false;
            }
            $app.utils.deleteAppUser();
            $http.defaults.headers.common.Authorization = ' Basic ';
        };

        return service;
    }])
    .directive('restrict', function ($app) {
        return {
            restrict: 'A',
            priority: 100000,
            scope: {
                restrict: "@"
            },
            link: function ($scope, $element, $attrs) {
                var accessDenied,
                    user            = $app.globals.currentUser,
                    accessRoles     = $attrs.restrict.split(" ");

                //check if  matching roles.
                accessDenied = !$app.utils.hasAccess(user, accessRoles);

                if (accessDenied) {
                    $element.children().remove();
                    $element.remove();
                }
            }
        };
    });

==> steward-app-1.21.0.jar: client/src/app/common/authentication/authentication.js <==
/**
 * Created by ben on 2/12/15.
 */
angular.module("hms-authentication", ['ngCookies', 'hms-authentication-model'])
    .constant("UserRoles", {
        ROLE1: "Researcher",
        ROLE2: "DataSteward",
        ROLE3: "Admin"
    })
    .factory('HMSAuthenticationService', ['$http', '$q', '$app', 'HMSAuthenticationModel', function ($http, $q, $app, model) {

        var service     = {};

        service.Login = function () {
            return model.authenticate();
        };

        service.SetAuthHeader = function (username, password) {
            var authdata = $app.utils.toBase64(username + ':' + password);
            $http.defaults.headers.common['Authorization'] =  'Basic ' + authdata;
        };

        service.SetCredentials = function (username, password, roles) {
            var authdata = $app.utils.toBase64(username + ':' + password);
            $app.utils.setAppUser(username, authdata, roles);
        };

        service.ClearCredentials = function () {
            if($app.globals.currentUser !== undefined) {
                $app.globals.currentUser.isLoggedIn = false;
            }
            $app.utils.deleteAppUser();
            $http.defaults.headers.common.Authorization = ' Basic ';
        };

        return service;
    }])
    .directive('restrict', function ($app) {
        return {
            restrict: 'A',
            priority: 100000,
            scope: {
                restrict: "@"
            },
            link: function ($scope, $element, $attrs) {
                var accessDenied,
                    user            = $app.globals.currentUser,
                    accessRoles     = $attrs.restrict.split(" ");

                //check if  matching roles.
                accessDenied = !$app.utils.hasAccess(user, accessRoles);

                if (accessDenied) {
                    $element.children().remove();
                    $element.remove();
                }
            }
        };
    });
